@@ -1,7 +1,7 @@
 #! /usr/bin/env bash
 
 function bluer_sbc_parts() {
-    local task=$1
+    local task=${1:-open}
 
     local function_name=bluer_sbc_parts_$task
     if [[ $(type -t $function_name) == "function" ]]; then
