@@ -1,8 +1,6 @@
 from bluer_sbc.README.designs import (
     adapter_bus,
     battery_bus,
-    bryce,
-    cheshmak,
     nafha,
     pwm_generator,
     regulated_bus,
@@ -10,6 +8,7 @@ from bluer_sbc.README.designs import (
     template,
     ultrasonic_sensor_tester,
 )
+from bluer_sbc.README.designs.cheshmak import docs as cheshmak
 from bluer_sbc.README.designs.swallow import docs as swallow
 from bluer_sbc.README.designs.swallow_head import docs as swallow_head
 
@@ -17,7 +16,6 @@ from bluer_sbc.README.designs.swallow_head import docs as swallow_head
 docs = (
     adapter_bus.docs
     + battery_bus.docs
-    + bryce.docs
     + cheshmak.docs
     + nafha.docs
     + pwm_generator.docs
