@@ -36,9 +36,9 @@ items = ImageItems(
 )
 
 parts = {
-    "SLA-Battery": "",
-    "on-off-switch": "",
-    "charging-port": "",
+    "SLA-Battery": "12 V, 7.2 Ah, or more.",
+    "dc-switch": "12V DC 10 A",
+    "dc-power-plug": "",
     "dsn-vc288": "",
 }
 
