@@ -2,6 +2,7 @@ from bluer_objects import README
 from bluer_objects.README.items import ImageItems
 
 from bluer_sbc.README.designs.consts import assets2
+from bluer_sbc.README.designs import pwm_generator, battery_bus
 from bluer_sbc.README.design import design_doc
 
 image_template = assets2 + "nafha/{}?raw=true"
@@ -30,15 +31,18 @@ items = ImageItems(
             "20251103_215301.jpg",
             "20251103_215319.jpg",
             "20251116_224456.jpg",
+            "20251124_094940.jpg",
+            "20251125_203403.jpg",
         ]
     },
 )
 
 parts = {
-    "dsn-vc288": "",
-    "dc-power-plug": "",
-    "pwm-manual-dc-motor-controller": "",
-    "heater-element": "12 V, 4.5 Ω, 32 w",
+    **battery_bus.parts,
+    **pwm_generator.parts,
+    **{
+        "heater-element": "12 V, 4.5 Ω, 32 w",
+    },
 }
 
 docs = [
