@@ -2,6 +2,7 @@ from bluer_objects import README
 from bluer_objects.README.items import ImageItems
 
 from bluer_sbc.README.designs.consts import assets2
+from bluer_sbc.README.design import design_doc
 
 
 image_template = assets2 + "ultrasonic-sensor-tester/{}?raw=true"
@@ -17,3 +18,10 @@ marquee = README.Items(
 )
 
 items = ImageItems({image_template.format(f"{index:02}.jpg"): "" for index in range(6)})
+
+docs = [
+    design_doc(
+        "ultrasonic-sensor-tester",
+        items,
+    )
+]
