@@ -21,6 +21,12 @@ parser.add_argument(
     default=1,
     help="0 | 1",
 )
+parser.add_argument(
+    "--generate_grid",
+    type=int,
+    default=1,
+    help="0 | 1",
+)
 parser.add_argument(
     "--verbose",
     type=int,
@@ -32,6 +38,7 @@ args = parser.parse_args()
 success = False
 if args.task == "adjust":
     success = db_of_parts.adjust(
+        generate_grid=args.generate_grid == 1,
         dryrun=args.dryrun == 1,
         verbose=args.verbose == 1,
     )
