@@ -70,7 +70,7 @@ db_of_parts["Polyfuse"] = Part(
 db_of_parts["rpi"] = Part(
     info=[
         "Raspberry Pi.",
-        "3B+ is preferred and 4B is in progress 🔥",
+        "3B+/4B.",
     ],
     images=[
         "rpi3bplus.png",
@@ -646,6 +646,15 @@ db_of_parts["mcb"] = Part(
     ],
 )
 
+db_of_parts["dc-circuit-breaker"] = Part(
+    info=[
+        "DC circuit breaker",
+    ],
+    images=[
+        "mcb-3.jpg",
+    ],
+)
+
 db_of_parts["ac-switch"] = Part(
     info=[
         "AC switch",
@@ -692,6 +701,25 @@ db_of_parts["power-adapter"] = Part(
     ],
 )
 
+db_of_parts["relay"] = Part(
+    info=[
+        "relay",
+    ],
+    images=[
+        "relay.jpg",
+    ],
+)
+
+db_of_parts["heavy-duty-pipe-clamp"] = Part(
+    info=[
+        "heavy duty pipe clamp",
+    ],
+    images=[
+        "heavy-duty-pipe-clamp.jpg",
+    ],
+)
+
+
 db_of_parts["template"] = Part(
     info=[
         "template",
